@@ -6,8 +6,8 @@ import math
 import weakref
 
 import dask
-from tornado import gen
 from tornado.locks import Event
+from tornado import gen
 
 from .adaptive import Adaptive
 from .cluster import Cluster
@@ -19,6 +19,7 @@ from ..utils import (
     parse_bytes,
     parse_timedelta,
     import_term,
+    TimeoutError,
 )
 from ..scheduler import Scheduler
 from ..security import Security
@@ -602,6 +603,6 @@ async def run_spec(spec: dict, *args):
 @atexit.register
 def close_clusters():
     for cluster in list(SpecCluster._instances):
-        with ignoring(gen.TimeoutError):
+        with ignoring((gen.TimeoutError, TimeoutError)):
             if cluster.status != "closed":
                 cluster.close(timeout=10)
