@@ -37,6 +37,21 @@ class SchedulerPlugin(object):
     >>> scheduler.add_plugin(plugin)  # doctest: +SKIP
     """
 
+    async def start(self, scheduler):
+        """ Run when the scheduler starts up
+
+        This runs at the end of the Scheduler startup process
+        """
+        pass
+
+    async def close(self):
+        """ Run when the scheduler closes down
+
+        This runs at the beginning of the Scheduler shutdown process, but after
+        workers have been asked to shut down gracefully
+        """
+        pass
+
     def update_graph(self, scheduler, dsk=None, keys=None, restrictions=None, **kwargs):
         """ Run when a new graph / tasks enter the scheduler """
 
