@@ -2,7 +2,6 @@ import asyncio
 import cloudpickle
 import pickle
 from collections import defaultdict
-from datetime import timedelta
 import json
 import operator
 import re
@@ -26,7 +25,7 @@ from distributed.client import wait
 from distributed.metrics import time
 from distributed.protocol.pickle import dumps
 from distributed.worker import dumps_function, dumps_task
-from distributed.utils import tmpfile, typename
+from distributed.utils import tmpfile, typename, TimeoutError
 from distributed.utils_test import (  # noqa: F401
     captured_logger,
     cleanup,
@@ -146,8 +145,8 @@ def test_no_valid_workers(client, s, a, b, c):
 
     assert s.tasks[x.key] in s.unrunnable
 
-    with pytest.raises(gen.TimeoutError):
-        yield gen.with_timeout(timedelta(milliseconds=50), x)
+    with pytest.raises(TimeoutError):
+        yield asyncio.wait_for(x, 0.05)
 
 
 @gen_cluster(client=True, nthreads=[("127.0.0.1", 1)] * 3)
@@ -166,8 +165,8 @@ def test_no_workers(client, s):
 
     assert s.tasks[x.key] in s.unrunnable
 
-    with pytest.raises(gen.TimeoutError):
-        yield gen.with_timeout(timedelta(milliseconds=50), x)
+    with pytest.raises(TimeoutError):
+        yield asyncio.wait_for(x, 0.05)
 
 
 @gen_cluster(nthreads=[])
@@ -597,6 +596,19 @@ def test_coerce_address():
         yield [w.close() for w in [a, b, c]]
 
 
+@pytest.mark.asyncio
+async def test_config_stealing(cleanup):
+    # Regression test for https://github.com/dask/distributed/issues/3409
+
+    with dask.config.set({"distributed.scheduler.work-stealing": True}):
+        async with Scheduler(port=0) as s:
+            assert "stealing" in s.extensions
+
+    with dask.config.set({"distributed.scheduler.work-stealing": False}):
+        async with Scheduler(port=0) as s:
+            assert "stealing" not in s.extensions
+
+
 @pytest.mark.skipif(
     sys.platform.startswith("win"), reason="file descriptors not really a thing"
 )
@@ -657,11 +669,11 @@ def test_story(c, s, a, b):
 
 @gen_cluster(nthreads=[], client=True)
 def test_scatter_no_workers(c, s):
-    with pytest.raises(gen.TimeoutError):
+    with pytest.raises(TimeoutError):
         yield s.scatter(data={"x": 1}, client="alice", timeout=0.1)
 
     start = time()
-    with pytest.raises(gen.TimeoutError):
+    with pytest.raises(TimeoutError):
         yield c.scatter(123, timeout=0.1)
     assert time() < start + 1.5
 
