@@ -3,8 +3,8 @@ from collections import defaultdict
 import logging
 import uuid
 
-from tornado import gen
 import tornado.locks
+from tornado import gen
 
 try:
     from cytoolz import merge
@@ -13,7 +13,7 @@ except ImportError:
 
 from .client import Future, _get_global_client, Client
 from .metrics import time
-from .utils import tokey, log_errors
+from .utils import tokey, log_errors, TimeoutError
 from .worker import get_client
 
 logger = logging.getLogger(__name__)
@@ -82,8 +82,11 @@ class VariableExtension(object):
             else:
                 left = None
             if left and left < 0:
-                raise gen.TimeoutError()
-            await self.started.wait(timeout=left)
+                raise TimeoutError()
+            try:
+                await self.started.wait(timeout=left)
+            except gen.TimeoutError:
+                raise TimeoutError("Timed out waiting for Variable.get")
         record = self.variables[name]
         if record["type"] == "Future":
             key = record["value"]
